@@ -80,8 +80,8 @@ def orthologMapper(dataset, biomartFilePath, originalGeneColumn, transformGeneCo
 
     :param dataset: dataset to find orthologs
     :param biomartFilePath: file path of csv from biomart to perform the mapping
-    :param originalGeneColumn: column name in biomart file
-    :param transformGeneColumn: column name in biomart file
+    :param originalGeneColumn: column name of original gene in biomart file
+    :param transformGeneColumn: column name of gene in biomart file
     :param varName: What set of data in .var to transform
     :return: void, mutates dataset
     """
