@@ -73,7 +73,7 @@ def pearsonViz(dataset_filtered, plotName, cellTypeColumnName, row_cluster=True,
     for i in range(dataset_filtered.uns[plotName].shape[0]):
         y_ticks.append('Feature ' + str(i + 1))
 
-    if row_cluster:
+    if row_cluster or col_cluster:
         sns.set(font_scale=1)
         cluster = sns.clustermap(dataset_filtered.uns[plotName],
                                  row_cluster=row_cluster,
@@ -92,11 +92,11 @@ def pearsonViz(dataset_filtered, plotName, cellTypeColumnName, row_cluster=True,
     if path is None and display is True:
         plt.show()
     if path is not None and display is False:
-        plt.savefig(path, dpi)
+        plt.savefig(path, dpi=dpi)
         plt.close()
     if path is not None and display is True:
         plt.show()
-        plt.savefig(path, dpi)
+        plt.savefig(path, dpi=dpi)
 
 
 def UMAP_Projection(dataset_filtered, cellTypeColumnName, projectionName, UMAPName, n_neighbors, metric='euclidean',
@@ -164,9 +164,9 @@ def UMAP_Viz(dataset_filtered, UMAPName, cellTypeColumnName, colorScheme='Paired
             plt.show()
         if display is True and path is not None:
             plt.show()
-            plt.savefig(path, dpi)
+            plt.savefig(path, dpi=dpi)
         if display is False and path is not None:
-            plt.savefig(path, dpi)
+            plt.savefig(path, dpi=dpi)
             plt.close()
     else:
         subsetted = dataset_filtered[dataset_filtered.obs[cellTypeColumnName].isin(subset)]
@@ -189,9 +189,9 @@ def UMAP_Viz(dataset_filtered, UMAPName, cellTypeColumnName, colorScheme='Paired
             plt.show()
         if display is True and path is not None:
             plt.show()
-            plt.savefig(path, dpi)
+            plt.savefig(path, dpi=dpi)
         if display is False and path is not None:
-            plt.savefig(path, dpi)
+            plt.savefig(path, dpi=dpi)
             plt.close()
 
 
@@ -237,9 +237,9 @@ def featurePlots(dataset_filtered, num_patterns, projectionName, UMAPName, obsCo
                 plt.show()
             if path is not None and display is True:
                 plt.show()
-                plt.savefig(path + str(i) + ".png", dpi)
+                plt.savefig(path + str(i) + ".png", dpi=dpi)
             if path is not None and display is False:
-                plt.savefig(path + str(i) + ".png", dpi)
+                plt.savefig(path + str(i) + ".png", dpi=dpi)
                 plt.close()
     else:
         for i in range(num_patterns):
@@ -255,8 +255,8 @@ def featurePlots(dataset_filtered, num_patterns, projectionName, UMAPName, obsCo
                 plt.show()
             if path is not None and display is True:
                 plt.show()
-                plt.savefig(path + str(i+1) + ".png", dpi)
+                plt.savefig(path + str(i+1) + ".png", dpi=dpi)
             if path is not None and display is False:
-                plt.savefig(path + str(i+1) + ".png", dpi)
+                plt.savefig(path + str(i+1) + ".png", dpi=dpi)
                 plt.close()
 
